Placement class

Constructors

Placement({String? placementName, String? rewardName, int? placementId, int? rewardAmount})

Properties

hashCode → int
The hash code for this object.
no setterinherited
placementId → int?
final
placementName → String?
final
rewardAmount → int?
final
rewardName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited